==> qtjambi-remoteobjects-5.15.12-sources.jar: io/qt/remoteobjects/QAbstractItemModelReplica.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QAbstractItemModelReplica</p>
 */
public final class QAbstractItemModelReplica extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractItemModelReplica.class);
    

    public final Signal0 initialized = new Signal0();
    
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<java.lang.Integer> availableRoles(){
        return availableRoles_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<java.lang.Integer> availableRoles_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasData(io.qt.core.QModelIndex index, int role){
        return hasData_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), role);
    }
    
    @io.qt.QtUninvokable
    private native boolean hasData_native_cref_QModelIndex_int_constfct(long __this__nativeId, long index, int role);
    
    @io.qt.QtUninvokable
    public final boolean isInitialized(){
        return isInitialized_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isInitialized_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final long rootCacheSize(){
        return rootCacheSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native long rootCacheSize_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QItemSelectionModel selectionModel(){
        return selectionModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QItemSelectionModel selectionModel_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setRootCacheSize(long rootCacheSize){
        setRootCacheSize_native_size_t(QtJambi_LibraryUtilities.internal.nativeId(this), rootCacheSize);
    }
    
    @io.qt.QtUninvokable
    private native void setRootCacheSize_native_size_t(long __this__nativeId, long rootCacheSize);
    
    @io.qt.QtUninvokable
    public int columnCount(io.qt.core.QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @io.qt.QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    @io.qt.QtUninvokable
    public java.lang.Object data(io.qt.core.QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, long index, int role);
    
    @io.qt.QtUninvokable
    public io.qt.core.Qt.ItemFlags flags(io.qt.core.QModelIndex index){
        return new io.qt.core.Qt.ItemFlags(flags_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index)));
    }
    
    @io.qt.QtUninvokable
    private native int flags_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    @io.qt.QtUninvokable
    public boolean hasChildren(io.qt.core.QModelIndex parent){
        return hasChildren_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasChildren_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    @io.qt.QtUninvokable
    public java.lang.Object headerData(int section, io.qt.core.Qt.Orientation orientation, int role){
        return headerData_native_int_Qt_Orientation_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), section, orientation.value(), role);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.Object headerData_native_int_Qt_Orientation_int_constfct(long __this__nativeId, int section, int orientation, int role);
    
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex index(int row, int column, io.qt.core.QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, long parent);
    
    @io.qt.QtUninvokable
    public io.qt.core.QModelIndex parent(io.qt.core.QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    @io.qt.QtUninvokable
    public java.util.Map<java.lang.Integer, io.qt.core.QByteArray> roleNames(){
        return roleNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.util.Map<java.lang.Integer, io.qt.core.QByteArray> roleNames_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public int rowCount(io.qt.core.QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @io.qt.QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    @io.qt.QtUninvokable
    public boolean setData(io.qt.core.QModelIndex index, java.lang.Object value, int role){
        return setData_native_cref_QModelIndex_cref_QVariant_int(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), value, role);
    }
    
    @io.qt.QtUninvokable
    private native boolean setData_native_cref_QModelIndex_cref_QVariant_int(long __this__nativeId, long index, java.lang.Object value, int role);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QAbstractItemModelReplica(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-remoteobjects-5.15.14-sources.jar: io/qt/remoteobjects/QAbstractItemModelReplica.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QAbstractItemModelReplica</p>
 */
public final class QAbstractItemModelReplica extends io.qt.core.QAbstractItemModel
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QAbstractItemModelReplica.class);
    

    public final @NonNull Signal0 initialized = new Signal0();
    
    @QtUninvokable
    public final io.qt.core.@NonNull QVector<java.lang.@QtPrimitiveType@NonNull Integer> availableRoles(){
        return availableRoles_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QVector<java.lang.@QtPrimitiveType Integer> availableRoles_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean hasData(io.qt.core.@NonNull QModelIndex index, int role){
        return hasData_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), role);
    }
    
    @QtUninvokable
    private native boolean hasData_native_cref_QModelIndex_int_constfct(long __this__nativeId, long index, int role);
    
    @QtUninvokable
    public final boolean isInitialized(){
        return isInitialized_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isInitialized_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final long rootCacheSize(){
        return rootCacheSize_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native long rootCacheSize_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@Nullable QItemSelectionModel selectionModel(){
        return selectionModel_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QItemSelectionModel selectionModel_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void setRootCacheSize(long rootCacheSize){
        setRootCacheSize_native_size_t(QtJambi_LibraryUtilities.internal.nativeId(this), rootCacheSize);
    }
    
    @QtUninvokable
    private native void setRootCacheSize_native_size_t(long __this__nativeId, long rootCacheSize);
    
    @QtUninvokable
    public int columnCount(io.qt.core.@NonNull QModelIndex parent){
        return columnCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native int columnCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    @QtUninvokable
    public java.lang.Object data(io.qt.core.@NonNull QModelIndex index, int role){
        return data_native_cref_QModelIndex_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), role);
    }
    
    @QtUninvokable
    private native java.lang.Object data_native_cref_QModelIndex_int_constfct(long __this__nativeId, long index, int role);
    
    @QtUninvokable
    public io.qt.core.Qt.@NonNull ItemFlags flags(io.qt.core.@NonNull QModelIndex index){
        return new io.qt.core.Qt.ItemFlags(flags_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index)));
    }
    
    @QtUninvokable
    private native int flags_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    @QtUninvokable
    public boolean hasChildren(io.qt.core.@NonNull QModelIndex parent){
        return hasChildren_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native boolean hasChildren_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    @QtUninvokable
    public java.lang.Object headerData(int section, io.qt.core.Qt.@NonNull Orientation orientation, int role){
        return headerData_native_int_Qt_Orientation_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), section, orientation.value(), role);
    }
    
    @QtUninvokable
    private native java.lang.Object headerData_native_int_Qt_Orientation_int_constfct(long __this__nativeId, int section, int orientation, int role);
    
    @QtUninvokable
    public io.qt.core.@NonNull QModelIndex index(int row, int column, io.qt.core.@NonNull QModelIndex parent){
        return index_native_int_int_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), row, column, QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex index_native_int_int_cref_QModelIndex_constfct(long __this__nativeId, int row, int column, long parent);
    
    @QtUninvokable
    public io.qt.core.@NonNull QModelIndex parent(io.qt.core.@NonNull QModelIndex index){
        return parent_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index));
    }
    
    @QtUninvokable
    private native io.qt.core.QModelIndex parent_native_cref_QModelIndex_constfct(long __this__nativeId, long index);
    
    @QtUninvokable
    public java.util.@NonNull Map<java.lang.@QtPrimitiveType@NonNull Integer, io.qt.core.@NonNull QByteArray> roleNames(){
        return roleNames_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.util.Map<java.lang.@QtPrimitiveType Integer, io.qt.core.QByteArray> roleNames_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public int rowCount(io.qt.core.@NonNull QModelIndex parent){
        return rowCount_native_cref_QModelIndex_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(parent));
    }
    
    @QtUninvokable
    private native int rowCount_native_cref_QModelIndex_constfct(long __this__nativeId, long parent);
    
    @QtUninvokable
    public boolean setData(io.qt.core.@NonNull QModelIndex index, java.lang.Object value, int role){
        return setData_native_cref_QModelIndex_cref_QVariant_int(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(index), value, role);
    }
    
    @QtUninvokable
    private native boolean setData_native_cref_QModelIndex_cref_QVariant_int(long __this__nativeId, long index, java.lang.Object value, int role);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QAbstractItemModelReplica(QPrivateConstructor p) { super(p); } 
    
}
